slicetools

package
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 25, 2026 License: MIT Imports: 0 Imported by: 0

Documentation

Overview

Package slicetools provides shared helpers for reusing scratch slices.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Resize

func Resize[T any](buffer *[]T, size int) []T

Resize returns a slice of size elements, reusing buffer's allocation when possible.

func ResizeZero

func ResizeZero[T any](buffer *[]T, size int) []T

ResizeZero returns a zeroed slice of size elements, reusing buffer's allocation when possible.

Types

This section is empty.

Jump to