Documentation
¶
Overview ¶
Package slicetools provides shared helpers for reusing scratch slices.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ResizeZero ¶
ResizeZero returns a zeroed slice of size elements, reusing buffer's allocation when possible.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.